@@ -6,6 +6,7 @@ use Moose::Role;
 use 5.010;
 use mro 'c3';
 
+use DateTime;
 use DateTime::Locale;
 use DateTime::TimeZone;
 use MooseX::Types::DateTime;
@@ -13,14 +14,7 @@ use Carp;
 
 requires 'parse_datetime';
 
-our $VERSION = '00.01_02';
-
-has 'pattern' => (
-	isa         => 'Maybe[Str]'
-	, is        => 'rw'
-	, required  => 1
-	, predicate => 'has_pattern'
-);
+our $VERSION = '00.01_03';
 
 has 'locale' => (
 	isa         => 'DateTime::Locale'
@@ -42,15 +36,6 @@ has 'debug' => ( isa => 'Bool', is => 'ro', default => 0 );
 around 'parse_datetime' => sub {
 	my ( $sub, $self, $time, $override, @args ) = @_;
 
-
-	## Set Pattern: from args, then from object
-	my $pattern = $override->{ pattern }
-		// $self->has_pattern
-		? $self->pattern
-		: croak "No pattern supplied to constructor or the call to parse_datetime"
-	;
-
-
 	## Set Timezone: from args, then from object
 	my $timezone = $override->{ timezone };
 	if ( not defined $timezone ) {
@@ -86,17 +71,14 @@ around 'parse_datetime' => sub {
 		};
 	}
 
+	my $env = {
+		timezone   => $timezone
+		, locale   => $locale
+		, override => $override
+	};
+
 	## Calls the sub ( time, env, addtl args )
-	my $dt = $self->$sub(
-		$time
-		, {
-			timezone   => $timezone
-			, locale   => $locale
-			, pattern  => $pattern
-			, override => $override
-		}
-		, @args
-	);
+	my $dt = $self->$sub( $time , $env , @args );
 
 	warn "Module did not return DateTime object"
 		if ! blessed $dt eq 'DateTime'
@@ -146,16 +128,13 @@ __END__
 
 =head1 NAME
 
-DateTimeX::Format - A base class for building next generation DateTime abstraction layers
+DateTimeX::Format - Moose Roles for building next generation DateTime formats
 
 =head1 SYNOPSIS
 
 	package DateTimeX::Format::Bleh;
 	with 'DateTimeX::Format';
 
-	## If your module doesn't require a user sent pattern
-	has '+pattern' => ( default => 'Undef' );
-
 	sub parse_datetime {
 		my ( $time, $env, @args ) = @_;
 		# expr;
@@ -165,13 +144,12 @@ DateTimeX::Format - A base class for building next generation DateTime abstracti
 		locale     => $locale
 		, timezone => $timezone
 		, debug    => 0|1
-		, defaults =>0|1
+		, defaults => 0|1
 	});
 
 	$dt->debug(0);
 	$dt->timezone( $timezone );
 	$dt->locale( $locale );
-	$dt->pattern( $pattern );
 	$dt->defaults(1);
 
 	$dt->parse_datetime( $time, {locale=>$locale_for_call} );
@@ -181,8 +159,14 @@ DateTimeX::Format - A base class for building next generation DateTime abstracti
 		, locale  => $locale_for_call
 	};
 	$dt->parse_datetime( $time, $env, @additional_arguments );
-
 	$dt->parse_datetime( $time, {timezone=>$timezone_for_call} )
+	
+	## if your module requires a pattern, or has variable time-input formats
+	## see the Moose::Role DateTimeX::Format::CustomPattern
+	package DateTimeX::Format::Strptime;
+	with 'DateTimeX::Format::CustomPattern';
+	with 'DateTimeX::Format';
+
 
 =head1 DESCRIPTION
 
